@@ -1,6 +1,8 @@
 #ifndef NEWSBOAT_CONTROLLER_H_
 #define NEWSBOAT_CONTROLLER_H_
 
+#include <memory>
+
 #include <libxml/tree.h>
 
 #include "cache.h"
@@ -10,7 +12,6 @@
 #include "feedcontainer.h"
 #include "filtercontainer.h"
 #include "fslock.h"
-#include "opml.h"
 #include "queuemanager.h"
 #include "regexmanager.h"
 #include "reloader.h"
@@ -27,7 +28,7 @@ class View;
 class Controller {
 public:
 	Controller(ConfigPaths& configpaths);
-	~Controller();
+	~Controller() = default;
 	void set_view(View* vv);
 	View* get_view()
 	{
@@ -44,7 +45,7 @@ public:
 	void mark_all_read(unsigned int pos);
 	void mark_article_read(const std::string& guid, bool read);
 	void mark_all_read(const std::string& feedurl);
-	void mark_all_read(std::shared_ptr<RssFeed> feed)
+	void mark_all_read(RssFeed& feed)
 	{
 		rsscache->mark_all_read(feed);
 	}
@@ -53,8 +54,7 @@ public:
 	{
 		return refresh_on_start;
 	}
-	EnqueueResult enqueue_url(std::shared_ptr<RssItem> item,
-		std::shared_ptr<RssFeed> feed);
+	EnqueueResult enqueue_url(RssItem& item, RssFeed& feed);
 
 	void reload_urls_file();
 	void edit_urls_file();
@@ -64,10 +64,9 @@ public:
 		return &feedcontainer;
 	}
 
-	void write_item(std::shared_ptr<RssItem> item,
-		const std::string& filename);
-	void write_item(std::shared_ptr<RssItem> item, std::ostream& ostr);
-	std::string write_temporary_item(std::shared_ptr<RssItem> item);
+	void write_item(RssItem& item, const std::string& filename);
+	void write_item(RssItem& item, std::ostream& ostr);
+	std::string write_temporary_item(RssItem& item);
 
 	void update_config();
 
@@ -82,10 +81,7 @@ public:
 		return reloader.get();
 	}
 
-	void replace_feed(std::shared_ptr<RssFeed> oldfeed,
-		std::shared_ptr<RssFeed> newfeed,
-		unsigned int pos,
-		bool unattended);
+	void replace_feed(RssFeed& oldfeed, RssFeed& newfeed, unsigned int pos, bool unattended);
 
 	ConfigContainer* get_config()
 	{
@@ -99,7 +95,7 @@ public:
 
 	RemoteApi* get_api()
 	{
-		return api;
+		return api.get();
 	}
 
 	RegexManager& get_regexmanager()
@@ -119,7 +115,7 @@ public:
 
 private:
 	int import_opml(const std::string& opmlFile, const std::string& urlFile);
-	void export_opml();
+	void export_opml(bool version2);
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
 	int execute_commands(const std::vector<std::string>& cmds);
 
@@ -127,8 +123,8 @@ private:
 	void export_read_information(const std::string& readinfofile);
 
 	View* v;
-	UrlReader* urlcfg;
-	Cache* rsscache;
+	std::unique_ptr<UrlReader> urlcfg;
+	std::unique_ptr<Cache> rsscache;
 	bool refresh_on_start;
 	ConfigContainer cfg;
 	RssIgnores ign;
@@ -138,7 +134,7 @@ private:
 	ConfigParser cfgparser;
 	ColorManager colorman;
 	RegexManager rxman;
-	RemoteApi* api;
+	std::unique_ptr<RemoteApi> api;
 
 	FsLock fslock;
 
