@@ -14,8 +14,8 @@ public:
 		const std::string& url_file,
 		RemoteApi* a);
 	~FeedHqUrlReader() override;
-	nonstd::optional<std::string> reload() override;
-	std::string get_source() override;
+	std::optional<utils::ReadTextFileError> reload() override;
+	std::string get_source() const override;
 
 private:
 	ConfigContainer* cfg;
