@@ -13,15 +13,17 @@ public:
 
 	/// \brief Load URLs from the urls file.
 	///
-	/// \return A non-value on success, an error message otherwise.
-	nonstd::optional<std::string> reload() override;
+	/// \return A non-value on success, a structure with error info otherwise.
+	std::optional<utils::ReadTextFileError> reload() override;
 
-	std::string get_source() override;
+	std::string get_source() const override;
+
+	void add_url(const std::string& url, const std::vector<std::string>& url_tags);
 
 	/// \brief Write URLs back to the urls file.
 	///
 	/// \return A non-value on success, an error message otherwise.
-	nonstd::optional<std::string> write_config();
+	std::optional<std::string> write_config();
 
 private:
 	const std::string filename;
