@@ -11,16 +11,17 @@ namespace newsboat {
 
 class OpmlUrlReader : public UrlReader {
 public:
-	explicit OpmlUrlReader(ConfigContainer* c);
-	nonstd::optional<std::string> reload() override;
-	std::string get_source() override;
+	explicit OpmlUrlReader(ConfigContainer& c, const std::string& url_file);
+	std::optional<utils::ReadTextFileError> reload() override;
+	std::string get_source() const override;
 
 protected:
 	virtual void handle_node(xmlNode* node, const std::string& tag);
-	ConfigContainer* cfg;
+	ConfigContainer& cfg;
 
 private:
 	void rec_find_rss_outlines(xmlNode* node, std::string tag);
+	std::string file;
 };
 
 }
