@@ -11,11 +11,11 @@ class SelectFormAction : public FormAction {
 public:
 	enum class SelectionType { TAG, FILTER };
 
-	SelectFormAction(View*, std::string formstr, ConfigContainer* cfg);
-	~SelectFormAction() override;
+	SelectFormAction(View&, std::string formstr, ConfigContainer* cfg);
+	~SelectFormAction() override = default;
 	void prepare() override;
 	void init() override;
-	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
+	std::vector<KeyMapHintEntry> get_keymap_hint() const override;
 	void set_selected_value(const std::string& new_value)
 	{
 		value = new_value;
@@ -52,8 +52,8 @@ protected:
 
 private:
 	bool process_operation(Operation op,
-		bool automatic = false,
-		std::vector<std::string>* args = nullptr) override;
+		const std::vector<std::string>& args,
+		BindingType bindingType = BindingType::BindKey) override;
 	bool quit;
 	bool is_first_draw;
 	SelectionType type;
