@@ -3,6 +3,7 @@
 
 #include <curl/curl.h>
 #include <libxml/parser.h>
+#include <optional>
 #include <string>
 
 #include "remoteapi.h"
@@ -31,13 +32,8 @@ public:
 		const std::string& etag = "",
 		newsboat::RemoteApi* api = 0,
 		const std::string& cookie_cache = "");
-	Feed parse_url(const std::string& url,
-		time_t lastmodified = 0,
-		const std::string& etag = "",
-		newsboat::RemoteApi* api = 0,
-		const std::string& cookie_cache = "");
 	Feed parse_buffer(const std::string& buffer,
-		const std::string& url = "");
+		const std::string& url = "", std::optional<std::string> charset = std::nullopt);
 	Feed parse_file(const std::string& filename);
 	time_t get_last_modified()
 	{
