@@ -26,8 +26,10 @@ FormAction::FormAction(View& vv, std::string formstr, ConfigContainer* cfg)
 	, head_line(f, "head")
 	, msg_line(f, "msg")
 	, qna_prompt_line(f, "qna_prompt")
+	, qna_input(f, "qna")
 	, qna_finish_operation(QnaFinishAction::None)
 	, qna_history(nullptr)
+	, tab_count(0)
 {
 	if (cfg->get_configvalue_as_bool("show-keymap-hint") == false) {
 		set_value("showhint", "0");
@@ -455,7 +457,7 @@ void FormAction::start_qna(const std::vector<QnaPair>& prompts,
 
 void FormAction::finish_qna_question()
 {
-	qna_responses.push_back(get_value("qna_value"));
+	qna_responses.push_back(qna_input.get_value());
 	start_next_question();
 }
 
@@ -464,7 +466,7 @@ void FormAction::cancel_qna()
 	LOG(Level::DEBUG, "FormAction::cancel_qna");
 
 	qna_prompt_line.hide();
-	f.set("show_qna_input", "0");
+	qna_input.hide();
 	msg_line.show();
 	msg_line.set_text("");
 
@@ -478,8 +480,8 @@ void FormAction::qna_next_history()
 {
 	if (qna_history) {
 		std::string entry = qna_history->next_line();
-		set_value("qna_value", entry);
-		set_value("qna_value_pos", std::to_string(entry.length()));
+		qna_input.set_value(entry);
+		qna_input.set_position(entry.length());
 	}
 }
 
@@ -487,8 +489,102 @@ void FormAction::qna_previous_history()
 {
 	if (qna_history) {
 		std::string entry = qna_history->previous_line();
-		set_value("qna_value", entry);
-		set_value("qna_value_pos", std::to_string(entry.length()));
+		qna_input.set_value(entry);
+		qna_input.set_position(entry.length());
+	}
+}
+
+void FormAction::clear_line()
+{
+	qna_input.set_value("");
+	qna_input.set_position(0);
+}
+
+void FormAction::clear_eol()
+{
+	unsigned int pos = qna_input.get_position();
+	std::string val = qna_input.get_value();
+	val.erase(pos, val.length());
+	qna_input.set_value(val);
+	qna_input.set_position(val.length());
+	LOG(Level::DEBUG, "View::clear_eol: cleared to end of line");
+}
+
+void FormAction::delete_word()
+{
+	std::string::size_type curpos = qna_input.get_position();
+	std::string val = qna_input.get_value();
+	std::string::size_type firstpos = curpos;
+	LOG(Level::DEBUG, "View::delete_word: before val = %s", val);
+	if (firstpos >= val.length() || ::isspace(val[firstpos])) {
+		if (firstpos != 0 && firstpos >= val.length()) {
+			firstpos = val.length() - 1;
+		}
+		while (firstpos > 0 && ::isspace(val[firstpos])) {
+			--firstpos;
+		}
+	}
+	while (firstpos > 0 && !::isspace(val[firstpos])) {
+		--firstpos;
+	}
+	if (firstpos != 0) {
+		firstpos++;
+	}
+	val.erase(firstpos, curpos - firstpos);
+	LOG(Level::DEBUG, "View::delete_word: after val = %s", val);
+	qna_input.set_value(val);
+	qna_input.set_position(firstpos);
+}
+
+void FormAction::handle_cmdline_completion()
+{
+	std::string fragment = qna_input.get_value();
+	if (fragment != last_fragment || fragment == "") {
+		last_fragment = fragment;
+		suggestions = get_suggestions(fragment);
+		tab_count = 0;
+	}
+	tab_count++;
+	std::string suggestion;
+	switch (suggestions.size()) {
+	case 0:
+		LOG(Level::DEBUG, "FormAction::handle_cmdline_completion: found no suggestion for `%s'",
+			fragment);
+		// direct call to ncurses - we beep to signal that there is no suggestion available, just like vim
+		::beep();
+		return;
+	case 1:
+		suggestion = suggestions[0];
+		break;
+	default:
+		suggestion = suggestions[(tab_count - 1) % suggestions.size()];
+		break;
+	}
+	qna_input.set_value(suggestion);
+	qna_input.set_position(suggestion.length());
+	last_fragment = suggestion;
+}
+
+void FormAction::handle_qna_event(std::string event, bool inside_cmd)
+{
+	if (event == "ESC") {
+		cancel_qna();
+	} else if (inside_cmd && event == "TAB") {
+		handle_cmdline_completion();
+	} else if (event == "UP") {
+		qna_previous_history();
+	} else if (event == "DOWN") {
+		qna_next_history();
+	} else if (event == "ENTER") {
+		finish_qna_question();
+	} else if (event == "^U") {
+		clear_line();
+	} else if (event == "^K") {
+		clear_eol();
+	} else if (event == "^G") {
+		cancel_qna();
+	} else if (event == "^W") {
+		delete_word();
 	}
 }
 
@@ -643,18 +739,17 @@ void FormAction::start_next_question()
 	 */
 	if (qna_prompts.size() > 0) {
 		qna_prompt_line.set_text(qna_prompts[0].first);
-		f.set("qna_value", qna_prompts[0].second);
+		qna_input.set_value(qna_prompts[0].second);
 
 		qna_prompt_line.show();
-		f.set("show_qna_input", "1");
+		qna_input.show();
 		msg_line.hide();
 
 		f.set_focus("qnainput");
 
 		// Set position to 0 and back to ensure that the text is visible
 		draw_form();
-		set_value("qna_value_pos",
-			std::to_string(qna_prompts[0].second.length()));
+		qna_input.set_position(qna_prompts[0].second.length());
 
 		qna_prompts.erase(qna_prompts.begin());
 	} else {
@@ -664,7 +759,7 @@ void FormAction::start_next_question()
 		 * finished_qna() method.
 		 */
 		qna_prompt_line.hide();
-		f.set("show_qna_input", "0");
+		qna_input.hide();
 		msg_line.show();
 		msg_line.set_text("");
 
