@@ -1,7 +1,7 @@
 #include "freshrssurlreader.h"
 
+#include "config.h"
 #include "configcontainer.h"
-#include "fileurlreader.h"
 #include "logger.h"
 #include "remoteapi.h"
 #include "utils.h"
@@ -19,11 +19,10 @@ FreshRssUrlReader::FreshRssUrlReader(ConfigContainer* c,
 
 FreshRssUrlReader::~FreshRssUrlReader() {}
 
-nonstd::optional<std::string> FreshRssUrlReader::reload()
+std::optional<utils::ReadTextFileError> FreshRssUrlReader::reload()
 {
 	urls.clear();
 	tags.clear();
-	alltags.clear();
 
 	if (cfg->get_configvalue_as_bool("freshrss-show-special-feeds")) {
 		std::vector<std::string> tmptags;
@@ -34,24 +33,7 @@ nonstd::optional<std::string> FreshRssUrlReader::reload()
 		tags[star_url] = tmptags;
 	}
 
-	FileUrlReader ur(file);
-	const auto error_message = ur.reload();
-	if (error_message.has_value()) {
-		LOG(Level::DEBUG, "Reloading failed: %s", error_message.value());
-		// Ignore errors for now: https://github.com/newsboat/newsboat/issues/1273
-	}
-
-	for (const auto& url : ur.get_urls()) {
-		if (utils::is_query_url(url)) {
-			urls.push_back(url);
-
-			auto url_tags = ur.get_tags(url);
-			tags[url] = url_tags;
-			for (const auto& tag : url_tags) {
-				alltags.insert(tag);
-			}
-		}
-	}
+	load_query_urls_from_file(file);
 
 	std::vector<TaggedFeedUrl> feedurls = api->get_subscribed_urls();
 	for (const auto& tagged : feedurls) {
@@ -63,14 +45,13 @@ nonstd::optional<std::string> FreshRssUrlReader::reload()
 		tags[tagged.first] = url_tags;
 		for (const auto& tag : url_tags) {
 			LOG(Level::DEBUG, "%s: added tag %s", url, tag);
-			alltags.insert(tag);
 		}
 	}
 
 	return {};
 }
 
-std::string FreshRssUrlReader::get_source()
+std::string FreshRssUrlReader::get_source() const
 {
 	return "FreshRSS";
 }
