@@ -189,7 +189,7 @@ bool ItemViewFormAction::process_operation(Operation op,
 		return enqueue_item_enclosure(*item, *feed, v, *rsscache);
 	case OP_SAVE: {
 		LOG(Level::INFO, "ItemViewFormAction::process_operation: saving article");
-		nonstd::optional<std::string> filename;
+		std::optional<std::string> filename;
 		switch (bindingType) {
 		case BindingType::Bind:
 			if (args.empty()) {
@@ -330,13 +330,13 @@ bool ItemViewFormAction::process_operation(Operation op,
 		switch (bindingType) {
 		case BindingType::Bind:
 			if (args.empty()) {
-				qna_responses = { args.front() };
-				this->finished_qna(QnaFinishAction::UpdateFlags);
-			} else {
 				std::vector<QnaPair> qna {
 					QnaPair(_("Flags: "), item->flags()),
 				};
 				this->start_qna(qna, QnaFinishAction::UpdateFlags);
+			} else {
+				qna_responses = { args.front() };
+				this->finished_qna(QnaFinishAction::UpdateFlags);
 			}
 			break;
 		case BindingType::Macro:
