@@ -1,7 +1,7 @@
 #include "minifluxurlreader.h"
 
+#include "config.h"
 #include "configcontainer.h"
-#include "fileurlreader.h"
 #include "logger.h"
 #include "remoteapi.h"
 #include "utils.h"
@@ -19,11 +19,10 @@ MinifluxUrlReader::MinifluxUrlReader(ConfigContainer* c,
 
 MinifluxUrlReader::~MinifluxUrlReader() {}
 
-nonstd::optional<utils::ReadTextFileError> MinifluxUrlReader::reload()
+std::optional<utils::ReadTextFileError> MinifluxUrlReader::reload()
 {
 	urls.clear();
 	tags.clear();
-	alltags.clear();
 
 	if (cfg->get_configvalue_as_bool("miniflux-show-special-feeds")) {
 		std::vector<std::string> tmptags;
@@ -31,23 +30,10 @@ nonstd::optional<utils::ReadTextFileError> MinifluxUrlReader::reload()
 		urls.push_back(star_url);
 		std::string star_tag = std::string("~") + _("Starred items");
 		tmptags.push_back(star_tag);
-		alltags.insert(star_tag);
 		tags[star_url] = tmptags;
 	}
 
-	FileUrlReader ur(file);
-	const auto error_message = ur.reload();
-	if (error_message.has_value()) {
-		LOG(Level::DEBUG, "Reloading failed: %s", error_message.value().message);
-		// Ignore errors for now: https://github.com/newsboat/newsboat/issues/1273
-	}
-
-	const std::vector<std::string>& file_urls(ur.get_urls());
-	for (const auto& url : file_urls) {
-		if (utils::is_query_url(url)) {
-			urls.push_back(url);
-		}
-	}
+	load_query_urls_from_file(file);
 
 	const std::vector<TaggedFeedUrl> feedurls = api->get_subscribed_urls();
 
@@ -57,14 +43,13 @@ nonstd::optional<utils::ReadTextFileError> MinifluxUrlReader::reload()
 		tags[url.first] = url.second;
 		for (const auto& tag : url.second) {
 			LOG(Level::DEBUG, "%s: added tag %s", url.first, tag);
-			alltags.insert(tag);
 		}
 	}
 
 	return {};
 }
 
-std::string MinifluxUrlReader::get_source()
+std::string MinifluxUrlReader::get_source() const
 {
 	return "Miniflux";
 }
