@@ -1,15 +1,11 @@
 #include "rssfeed.h"
 
 #include <algorithm>
-#include <cerrno>
 #include <cinttypes>
 #include <cstring>
 #include <curl/curl.h>
-#include <functional>
-#include <iostream>
 #include <langinfo.h>
 #include <random>
-#include <sstream>
 #include <string.h>
 #include <sys/utsname.h>
 #include <time.h>
@@ -17,13 +13,9 @@
 #include "cache.h"
 #include "config.h"
 #include "configcontainer.h"
-#include "confighandlerexception.h"
-#include "dbexception.h"
-#include "htmlrenderer.h"
 #include "logger.h"
 #include "scopemeasure.h"
 #include "strprintf.h"
-#include "tagsouppullparser.h"
 #include "utils.h"
 
 namespace newsboat {
@@ -172,7 +164,7 @@ std::shared_ptr<RssItem> RssFeed::get_item_by_guid_unlocked(
 	return std::shared_ptr<RssItem>(new RssItem(ch));
 }
 
-nonstd::optional<std::string> RssFeed::attribute_value(const std::string&
+std::optional<std::string> RssFeed::attribute_value(const std::string&
 	attribname) const
 {
 	if (attribname == "feedtitle") {
@@ -211,7 +203,7 @@ nonstd::optional<std::string> RssFeed::attribute_value(const std::string&
 		}
 		return "0";
 	}
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
 void RssFeed::update_items(std::vector<std::shared_ptr<RssFeed>> feeds)
