@@ -1,12 +1,11 @@
 #include "urlviewformaction.h"
 
-#include <sstream>
 #include <string>
 
 #include "config.h"
 #include "fmtstrformatter.h"
-#include "listformatter.h"
 #include "rssfeed.h"
+#include "stflrichtext.h"
 #include "strprintf.h"
 #include "utils.h"
 #include "view.h"
@@ -125,10 +124,10 @@ void UrlViewFormAction::prepare()
 	if (do_redraw) {
 		update_heading();
 
-		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> std::string {
+		auto render_line = [this](std::uint32_t line, std::uint32_t width) -> StflRichText {
 			(void)width;
 			const auto& link = links[line];
-			return utils::quote_for_stfl(strprintf::fmt("%2u  %s", line + 1, link.url));
+			return StflRichText::from_plaintext(strprintf::fmt("%2u  %s", line + 1, link.url));
 		};
 
 		urls_list.invalidate_list_content(links.size(), render_line);
@@ -155,7 +154,7 @@ void UrlViewFormAction::update_heading()
 	set_title(fmt.do_format(cfg->get_configvalue("urlview-title-format"), width));
 }
 
-const std::vector<KeyMapHintEntry>& UrlViewFormAction::get_keymap_hint() const
+std::vector<KeyMapHintEntry> UrlViewFormAction::get_keymap_hint() const
 {
 	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Quit")},
 		{OP_OPEN, _("Open in Browser")},
