@@ -11,6 +11,7 @@
 #include <langinfo.h>
 #include <libxml/uri.h>
 #include <mutex>
+#include <ncurses.h>
 #include <pwd.h>
 #include <sstream>
 #include <stfl.h>
@@ -64,7 +65,7 @@ std::vector<std::string> utils::tokenize_quoted(const std::string& str,
 	return result;
 }
 
-nonstd::optional<std::string> utils::extract_token_quoted(std::string& str,
+std::optional<std::string> utils::extract_token_quoted(std::string& str,
 	std::string delimiters)
 {
 	rust::String remaining = str;
@@ -705,7 +706,7 @@ std::string utils::make_title(const std::string& const_url)
 	return std::string(utils::bridged::make_title(const_url));
 }
 
-nonstd::optional<std::uint8_t> utils::run_interactively(
+std::optional<std::uint8_t> utils::run_interactively(
 	const std::string& command,
 	const std::string& caller)
 {
@@ -714,10 +715,10 @@ nonstd::optional<std::uint8_t> utils::run_interactively(
 		return exit_code;
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
-nonstd::optional<std::uint8_t> utils::run_non_interactively(
+std::optional<std::uint8_t> utils::run_non_interactively(
 	const std::string& command,
 	const std::string& caller)
 {
@@ -726,7 +727,7 @@ nonstd::optional<std::uint8_t> utils::run_non_interactively(
 		return exit_code;
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
 std::string utils::getcwd()
@@ -778,7 +779,7 @@ bool utils::is_valid_podcast_type(const std::string& mimetype)
 	return utils::bridged::is_valid_podcast_type(mimetype);
 }
 
-nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
+std::optional<LinkType> utils::podcast_mime_to_link_type(
 	const std::string& mimetype)
 {
 	std::int64_t result = 0;
@@ -786,7 +787,7 @@ nonstd::optional<LinkType> utils::podcast_mime_to_link_type(
 		return static_cast<LinkType>(result);
 	}
 
-	return nonstd::nullopt;
+	return std::nullopt;
 }
 
 std::string utils::string_from_utf8_lossy(const std::vector<std::uint8_t>& text)
@@ -900,4 +901,14 @@ std::string utils::mt_strf_localtime(const std::string& format, time_t t)
 	return std::string(buffer, written);
 }
 
+void utils::wait_for_keypress()
+{
+	initscr();
+	cbreak(); // Disable line buffering
+	raw(); // Make sure we return from getch on Ctrl+C instead of calling the signal handler
+	timeout(-1); // Make getch wait indefinitely
+	getch();
+	endwin(); // Restore terminal settings
+}
+
 } // namespace newsboat
