@@ -8,6 +8,7 @@
 #include <libgen.h>
 #include <limits.h>
 #include <ncurses.h>
+#include <optional>
 #include <pwd.h>
 #include <string.h>
 #include <sys/param.h>
@@ -18,8 +19,6 @@ extern "C" {
 #include <stfl.h>
 }
 
-#include "3rd-party/optional.hpp"
-
 #include "config.h"
 #include "colormanager.h"
 #include "controller.h"
@@ -70,7 +69,6 @@ View::View(Controller& c)
 	, rxman(c.get_regexmanager())
 	, is_inside_qna(false)
 	, is_inside_cmdline(false)
-	, tab_count(0)
 	, rsscache(nullptr)
 	, filters(ctrl.get_filtercontainer())
 	, colorman(ctrl.get_colormanager())
@@ -398,7 +396,7 @@ void View::open_in_pager(const std::string& filename)
 	pop_current_formaction();
 }
 
-nonstd::optional<std::uint8_t> View::open_in_browser(const std::string& url,
+std::optional<std::uint8_t> View::open_in_browser(const std::string& url,
 	const std::string& feedurl, const std::string& type, const std::string& title,
 	bool interactive)
 {
@@ -644,7 +642,7 @@ void View::push_urlview(const Links& links,
 	current_formaction = formaction_stack_size() - 1;
 }
 
-nonstd::optional<std::string> View::run_filebrowser(const std::string& default_filename)
+std::optional<std::string> View::run_filebrowser(const std::string& default_filename)
 {
 	auto filebrowser = std::make_shared<FileBrowserFormAction>(
 			*this, filebrowser_str, cfg);
@@ -653,12 +651,12 @@ nonstd::optional<std::string> View::run_filebrowser(const std::string& default_f
 	filebrowser->set_parent_formaction(get_current_formaction());
 	std::string res = run_modal(filebrowser, "filenametext");
 	if (res.empty()) {
-		return nonstd::nullopt;
+		return std::nullopt;
 	}
 	return res;
 }
 
-nonstd::optional<std::string> View::run_dirbrowser()
+std::optional<std::string> View::run_dirbrowser()
 {
 	auto dirbrowser = std::make_shared<DirBrowserFormAction>(
 			*this, filebrowser_str, cfg);
@@ -666,7 +664,7 @@ nonstd::optional<std::string> View::run_dirbrowser()
 	dirbrowser->set_parent_formaction(get_current_formaction());
 	std::string res = run_modal(dirbrowser, "filenametext");
 	if (res.empty()) {
-		return nonstd::nullopt;
+		return std::nullopt;
 	}
 	return res;
 }
@@ -1188,77 +1186,12 @@ void View::inside_cmdline(bool f)
 	is_inside_cmdline = f;
 }
 
-void View::clear_line(std::shared_ptr<FormAction> fa)
-{
-	fa->set_value("qna_value", "");
-	fa->set_value("qna_value_pos", "0");
-	LOG(Level::DEBUG, "View::clear_line: cleared line");
-}
-
-void View::clear_eol(std::shared_ptr<FormAction> fa)
-{
-	unsigned int pos = utils::to_u(fa->get_value("qna_value_pos"), 0);
-	std::string val = fa->get_value("qna_value");
-	val.erase(pos, val.length());
-	fa->set_value("qna_value", val);
-	fa->set_value("qna_value_pos", std::to_string(val.length()));
-	LOG(Level::DEBUG, "View::clear_eol: cleared to end of line");
-}
-
-void View::delete_word(std::shared_ptr<FormAction> fa)
-{
-	std::string::size_type curpos =
-		utils::to_u(fa->get_value("qna_value_pos"), 0);
-	std::string val = fa->get_value("qna_value");
-	std::string::size_type firstpos = curpos;
-	LOG(Level::DEBUG, "View::delete_word: before val = %s", val);
-	if (firstpos >= val.length() || ::isspace(val[firstpos])) {
-		if (firstpos != 0 && firstpos >= val.length()) {
-			firstpos = val.length() - 1;
-		}
-		while (firstpos > 0 && ::isspace(val[firstpos])) {
-			--firstpos;
-		}
-	}
-	while (firstpos > 0 && !::isspace(val[firstpos])) {
-		--firstpos;
-	}
-	if (firstpos != 0) {
-		firstpos++;
-	}
-	val.erase(firstpos, curpos - firstpos);
-	LOG(Level::DEBUG, "View::delete_word: after val = %s", val);
-	fa->set_value("qna_value", val);
-	fa->set_value("qna_value_pos", std::to_string(firstpos));
-}
-
 bool View::handle_qna_event(const std::string& event,
 	std::shared_ptr<FormAction> fa)
 {
 	if (is_inside_qna) {
-		LOG(Level::DEBUG,
-			"View::handle_qna_event: we're inside QNA input");
-		if (is_inside_cmdline && event == "TAB") {
-			handle_cmdline_completion(fa);
-			return true;
-		}
-		if (event == "ESC") {
-			fa->cancel_qna();
-		} else if (event == "UP") {
-			fa->qna_previous_history();
-		} else if (event == "DOWN") {
-			fa->qna_next_history();
-		} else if (event == "ENTER") {
-			fa->finish_qna_question();
-		} else if (event == "^U") {
-			clear_line(fa);
-		} else if (event == "^K") {
-			clear_eol(fa);
-		} else if (event == "^G") {
-			fa->cancel_qna();
-		} else if (event == "^W") {
-			delete_word(fa);
-		}
+		LOG(Level::DEBUG, "View::handle_qna_event: we're inside QNA input");
+		fa->handle_qna_event(event, is_inside_cmdline);
 
 		return true;
 	}
@@ -1276,38 +1209,6 @@ void View::handle_resize()
 	}
 }
 
-void View::handle_cmdline_completion(std::shared_ptr<FormAction> fa)
-{
-	std::string fragment = fa->get_value("qna_value");
-	if (fragment != last_fragment || fragment == "") {
-		last_fragment = fragment;
-		suggestions = fa->get_suggestions(fragment);
-		tab_count = 0;
-	}
-	tab_count++;
-	std::string suggestion;
-	switch (suggestions.size()) {
-	case 0:
-		LOG(Level::DEBUG,
-			"View::handle_cmdline_completion: found no suggestion "
-			"for "
-			"`%s'",
-			fragment);
-		// direct call to ncurses - we beep to signal that there is no suggestion available, just like vim
-		::beep();
-		return;
-	case 1:
-		suggestion = suggestions[0];
-		break;
-	default:
-		suggestion = suggestions[(tab_count - 1) % suggestions.size()];
-		break;
-	}
-	fa->set_value("qna_value", suggestion);
-	fa->set_value("qna_value_pos", std::to_string(suggestion.length()));
-	last_fragment = suggestion;
-}
-
 void View::ctrl_c_action(int /* sig */)
 {
 	LOG(Level::DEBUG, "caught SIGINT");
