@@ -30,9 +30,12 @@ static const auto ITEM_PUBDATE = time_t
 static const auto ITEM_LINK = std::string("https://example.com/see-more");
 static const auto ITEM_DESCRIPTON = std::string("<p>Hello, world!</p>");
 static const auto ITEM_DESCRIPTON_RENDERED = std::string("Hello, world!");
-static const auto ITEM_ENCLOSURE_URL =
+static const auto ITEM_PODCAST_ENCLOSURE_URL =
 	std::string("https://example.com/see-more.mp3");
-static const auto ITEM_ENCLOSURE_TYPE = std::string("audio/mpeg");
+static const auto ITEM_IMAGE_ENCLOSURE_URL =
+	std::string("https://example.com/see-more.png");
+static const auto ITEM_PODCAST_ENCLOSURE_TYPE = std::string("audio/mpeg");
+static const auto ITEM_IMAGE_ENCLOSURE_TYPE = std::string("image/png");
 static const auto ITEM_FLAGS = std::string("wasdhjkl");
 // Flags are sorted for rendering.
 static const auto ITEM_FLAGS_RENDERED = std::string("adhjklsw");
@@ -74,7 +77,7 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 	SECTION("Item without an enclosure") {
 		item->set_description(ITEM_DESCRIPTON, "text/html");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -91,9 +94,9 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 
 	SECTION("Item with an enclosure") {
 		item->set_description(ITEM_DESCRIPTON, "text/html");
-		item->set_enclosure_url(ITEM_ENCLOSURE_URL);
+		item->set_enclosure_url(ITEM_PODCAST_ENCLOSURE_URL);
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -102,19 +105,19 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
 			"Link: " + ITEM_LINK + '\n' +
 			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
-			"Podcast Download URL: " + ITEM_ENCLOSURE_URL + '\n' +
+			"Podcast Download URL: " + ITEM_PODCAST_ENCLOSURE_URL + '\n' +
 			" \n" +
 			ITEM_DESCRIPTON_RENDERED + '\n';
 
 		REQUIRE(result == expected);
 	}
 
-	SECTION("Item with an enclosure that has a MIME type") {
+	SECTION("Item with an enclosure that has a podcast MIME type") {
 		item->set_description(ITEM_DESCRIPTON, "text/html");
-		item->set_enclosure_url(ITEM_ENCLOSURE_URL);
-		item->set_enclosure_type(ITEM_ENCLOSURE_TYPE);
+		item->set_enclosure_url(ITEM_PODCAST_ENCLOSURE_URL);
+		item->set_enclosure_type(ITEM_PODCAST_ENCLOSURE_TYPE);
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -123,20 +126,45 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
 			"Link: " + ITEM_LINK + '\n' +
 			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
-			"Podcast Download URL: " + ITEM_ENCLOSURE_URL
-			+ " (type: " + ITEM_ENCLOSURE_TYPE + ")\n" +
+			"Podcast Download URL: " + ITEM_PODCAST_ENCLOSURE_URL
+			+ " (type: " + ITEM_PODCAST_ENCLOSURE_TYPE + ")\n" +
 			" \n" +
 			ITEM_DESCRIPTON_RENDERED + '\n';
 
 		REQUIRE(result == expected);
 	}
 
+	SECTION("Item with an enclosure that has an image MIME type") {
+		item->set_description(ITEM_DESCRIPTON, "text/html");
+		item->set_enclosure_url(ITEM_IMAGE_ENCLOSURE_URL);
+		item->set_enclosure_type(ITEM_IMAGE_ENCLOSURE_TYPE);
+
+		const auto result = item_renderer::to_plain_text(cfg, *item);
+
+		const auto expected = std::string() +
+			"Feed: " + FEED_TITLE + '\n' +
+			"Title: " + ITEM_TITLE + '\n' +
+			"Author: " + ITEM_AUTHOR + '\n' +
+			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
+			"Link: " + ITEM_LINK + '\n' +
+			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
+			" \n" +
+			"Image[1]\n" +
+			" \n" +
+			ITEM_DESCRIPTON_RENDERED + '\n' +
+			" \n" +
+			"Links: \n" +
+			"[1]: " + ITEM_IMAGE_ENCLOSURE_URL + " (image)\n";
+
+		REQUIRE(result == expected);
+	}
+
 	SECTION("Item with some links in the description") {
 		item->set_description(
 			ITEM_DESCRIPTON +
 			"<p>See also <a href='https://example.com'>this site</a>.</p>", "text/html");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -155,6 +183,31 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 
 		REQUIRE(result == expected);
 	}
+
+	SECTION("Item with enclosure and plaintext description") {
+		item->set_description(ITEM_DESCRIPTON, "text/plain");
+		item->set_enclosure_url("https://example.com/test.png");
+		item->set_enclosure_type("image/png");
+
+		const auto result = item_renderer::to_plain_text(cfg, *item);
+
+		const auto expected = std::string() +
+			"Feed: " + FEED_TITLE + '\n' +
+			"Title: " + ITEM_TITLE + '\n' +
+			"Author: " + ITEM_AUTHOR + '\n' +
+			"Date: Sun, 30 Sep 2018 19:34:25 +0000\n" +
+			"Link: " + ITEM_LINK + '\n' +
+			"Flags: " + ITEM_FLAGS_RENDERED + '\n' +
+			" \n" +
+			"Image[1]\n" +
+			" \n" +
+			ITEM_DESCRIPTON + '\n' +
+			" \n" +
+			"Links: \n" +
+			"[1]: https://example.com/test.png (image)\n";
+
+		REQUIRE(result == expected);
+	}
 }
 
 TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
@@ -188,7 +241,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 		" \n";
 
 	SECTION("If `text-width` is not set, text is rendered in 80 columns") {
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = header +
 			"Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nisl \n"
@@ -203,7 +256,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 	SECTION("If `text-width` is set to zero, text is rendered in 80 columns") {
 		cfg.set_configvalue("text-width", "0");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = header +
 			"Lorem ipsum dolor sit amet, consectetur adipiscing elit. Pellentesque nisl \n"
@@ -218,7 +271,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 	SECTION("Text is rendered in 37 columns") {
 		cfg.set_configvalue("text-width", "37");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = header +
 			"Lorem ipsum dolor sit amet, \n"
@@ -235,7 +288,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 	SECTION("Text is rendered in 120 columns") {
 		cfg.set_configvalue("text-width", "120");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = header +
 			"Lorem ipsum dolor sit amet, consectetur adipiscing elit. "
@@ -255,7 +308,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 			"&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;&gt;" // 10 characters
 			"Lorem ipsum dolor sit amet", "text/html");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = header +
 			"<<<<<<<<<<>>>>>>>>>>Lorem ipsum dolor\n"
@@ -294,7 +347,7 @@ TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 		" \n" +
 		"<test>\n";
 
-	const auto result = item_renderer::to_plain_text(cfg, item);
+	const auto result = item_renderer::to_plain_text(cfg, *item);
 	REQUIRE(result == expected);
 }
 
@@ -317,7 +370,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without a feed title") {
 		item->get_feedptr()->set_title("");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Title: " + ITEM_TITLE + '\n' +
@@ -333,7 +386,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without a title") {
 		item->set_title("");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -349,7 +402,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without an author") {
 		item->set_author("");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -365,7 +418,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without a link") {
 		item->set_link("");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -381,7 +434,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without an enclosure") {
 		item->set_description(ITEM_DESCRIPTON, "text/html");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -399,7 +452,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 	SECTION("Item without flags") {
 		item->set_flags("");
 
-		const auto result = item_renderer::to_plain_text(cfg, item);
+		const auto result = item_renderer::to_plain_text(cfg, *item);
 
 		const auto expected = std::string() +
 			"Feed: " + FEED_TITLE + '\n' +
@@ -437,7 +490,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		SECTION("internal renderer") {
 			cfg.set_configvalue("html-renderer", "internal");
 
-			const auto result = item_renderer::to_plain_text(cfg, item);
+			const auto result = item_renderer::to_plain_text(cfg, *item);
 
 			const auto expected = std::string() +
 				"Feed: " + FEED_TITLE + '\n' +
@@ -460,7 +513,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		SECTION("/bin/cat as a renderer") {
 			cfg.set_configvalue("html-renderer", "/bin/cat");
 
-			const auto result = item_renderer::to_plain_text(cfg, item);
+			const auto result = item_renderer::to_plain_text(cfg, *item);
 
 			const auto expected = std::string() +
 				"Feed: " + FEED_TITLE + '\n' +
@@ -486,7 +539,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		SECTION("internal renderer") {
 			cfg.set_configvalue("html-renderer", "internal");
 
-			const auto result = item_renderer::to_plain_text(cfg, item);
+			const auto result = item_renderer::to_plain_text(cfg, *item);
 
 			const auto expected = std::string() +
 				"Feed: " + FEED_TITLE + '\n' +
@@ -511,7 +564,7 @@ TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 		SECTION("/bin/cat as a renderer") {
 			cfg.set_configvalue("html-renderer", "/bin/cat");
 
-			const auto result = item_renderer::to_plain_text(cfg, item);
+			const auto result = item_renderer::to_plain_text(cfg, *item);
 
 			const auto expected = std::string() +
 				"Feed: " + FEED_TITLE + '\n' +
@@ -542,7 +595,7 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed title without "
 	std::tie(item, feed) = create_test_item(&rsscache);
 
 	const auto check = [&]() {
-		const auto result = item_renderer::get_feedtitle(item);
+		const auto result = item_renderer::get_feedtitle(*item);
 		REQUIRE(result == "Welcome, lovely strangers!");
 	};
 
@@ -573,7 +626,7 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed self-link "
 	feed->set_title("");
 	feed->set_link(feedlink);
 
-	const auto result = item_renderer::get_feedtitle(item);
+	const auto result = item_renderer::get_feedtitle(*item);
 	REQUIRE(result == feedlink);
 }
 
@@ -594,7 +647,7 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed URL "
 	feed->set_title("");
 	feed->set_link("");
 
-	const auto result = item_renderer::get_feedtitle(item);
+	const auto result = item_renderer::get_feedtitle(*item);
 	REQUIRE(result == feedurl);
 }
 
@@ -631,8 +684,8 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 			"{listitem text:\"<>test>\"}" +
 			"}";
 
-		std::vector<LinkPair> links;
-		const auto result = item_renderer::to_stfl_list(cfg, item, 80, 80, &rxman,
+		Links links;
+		const auto result = item_renderer::to_stfl_list(cfg, *item, 80, 80, &rxman,
 				"article", links);
 		REQUIRE(result.first == expected);
 	}
@@ -650,8 +703,8 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 			"{listitem text:\"<>html>&lt;test&gt;<>/html>\"}" +
 			"}";
 
-		std::vector<LinkPair> links;
-		const auto result = item_renderer::source_to_stfl_list(item, 80, 80, &rxman,
+		Links links;
+		const auto result = item_renderer::source_to_stfl_list(*item, 80, 80, &rxman,
 				"article");
 		REQUIRE(result.first == expected);
 	}
