@@ -16,9 +16,9 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 {
 	const auto check =
 		[]
-		(const FeedContainer& feedcontainer)
+		(const FeedContainer& feedcontainer, bool version2)
 	-> std::string {
-		xmlDocPtr opml = opml::generate(feedcontainer);
+		xmlDocPtr opml = opml::generate(feedcontainer, version2);
 
 		xmlBufferPtr buffer = xmlBufferCreate();
 
@@ -29,8 +29,8 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 		xmlFreeDoc(opml);
 
 		const std::string opmlText(
-			reinterpret_cast<char*>(buffer->content),
-			buffer->use);
+			reinterpret_cast<const char*>(xmlBufferContent(buffer)),
+			xmlBufferLength(buffer));
 
 		xmlBufferFree(buffer);
 		buffer = nullptr;
@@ -43,11 +43,11 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 
 		const std::string expectedOpmlText(
 			"<?xml version=\"1.0\"?>\n"
-			"<opml version=\"1.0\">"
+			"<opml version=\"2.0\">"
 			"<head><title>Newsboat - Exported Feeds</title></head>"
 			"<body/></opml>\n");
 
-		REQUIRE(check(feeds) == expectedOpmlText);
+		REQUIRE(check(feeds, true) == expectedOpmlText);
 	}
 
 	SECTION("A few feeds") {
@@ -64,9 +64,10 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 		feed = std::make_shared<RssFeed>(&rsscache, "https://example.com/feed2.xml");
 		feed->set_title("Feed 2");
 		feed->set_link("https://example.com/feed2/");
+		feed->set_tags({"tag", "tag,with,commas", "tag/with/slashes", "tag with spaces"});
 		feeds.add_feed(std::move(feed));
 
-		const std::string expectedOpmlText(
+		const std::string expectedOpml1Text(
 			"<?xml version=\"1.0\"?>\n"
 			"<opml version=\"1.0\">"
 			"<head><title>Newsboat - Exported Feeds</title></head>"
@@ -74,15 +75,38 @@ TEST_CASE("opml::generate creates an XML document with feed URLs in OPML format"
 			"<outline type=\"rss\" "
 			"xmlUrl=\"https://example.com/feed1.xml\" "
 			"htmlUrl=\"https://example.com/feed1/\" "
-			"title=\"Feed 1\"/>"
+			"title=\"Feed 1\" "
+			"text=\"Feed 1\"/>"
 			"<outline type=\"rss\" "
 			"xmlUrl=\"https://example.com/feed2.xml\" "
 			"htmlUrl=\"https://example.com/feed2/\" "
-			"title=\"Feed 2\"/>"
+			"title=\"Feed 2\" "
+			"text=\"Feed 2\"/>"
 			"</body>"
 			"</opml>\n");
 
-		REQUIRE(check(feeds) == expectedOpmlText);
+		const std::string expectedOpml2Text(
+			"<?xml version=\"1.0\"?>\n"
+			"<opml version=\"2.0\">"
+			"<head><title>Newsboat - Exported Feeds</title></head>"
+			"<body>"
+			"<outline type=\"rss\" "
+			"xmlUrl=\"https://example.com/feed1.xml\" "
+			"htmlUrl=\"https://example.com/feed1/\" "
+			"title=\"Feed 1\" "
+			"text=\"Feed 1\" "
+			"category=\"\"/>"
+			"<outline type=\"rss\" "
+			"xmlUrl=\"https://example.com/feed2.xml\" "
+			"htmlUrl=\"https://example.com/feed2/\" "
+			"title=\"Feed 2\" "
+			"text=\"Feed 2\" "
+			"category=\"tag,tag_with_commas,tag/with/slashes,tag with spaces\"/>"
+			"</body>"
+			"</opml>\n");
+
+		REQUIRE(check(feeds, false) == expectedOpml1Text);
+		REQUIRE(check(feeds, true) == expectedOpml2Text);
 	}
 }
 
@@ -274,6 +298,18 @@ TEST_CASE("import() skips URLs that are already present in UrlReader",
 	}
 }
 
+TEST_CASE("import() tags from category attribute", "[Opml]")
+{
+	FileUrlReader urlcfg;
+	REQUIRE_NOTHROW(
+		opml::import("file://" + utils::getcwd() + "/data/category.opml", urlcfg)
+	);
+
+	const std::vector<std::string> tags{"tag one", "tag_two", "tag/three"};
+	const auto& urls = urlcfg.get_urls();
+	REQUIRE(urls.size() == 1);
+	REQUIRE(urlcfg.get_tags(urls[0]) == tags);
+}
 // falls back to "url" if "xmlUrl" is absent
 
 // skips an entry if xmlUrl/url is absent
