@@ -1,12 +1,9 @@
 #include "opmlurlreader.h"
 
-#include <fstream>
 #include <map>
 #include <unistd.h>
 
 #include "3rd-party/catch.hpp"
-#include "test_helpers/misc.h"
-#include "test_helpers/tempfile.h"
 #include "utils.h"
 
 using namespace newsboat;
@@ -15,7 +12,7 @@ TEST_CASE("OPML URL reader gets the path to input file from \"opml-url\" "
 	"setting", "[OpmlUrlReader]")
 {
 	ConfigContainer cfg;
-	OpmlUrlReader reader(cfg);
+	OpmlUrlReader reader(cfg, "");
 
 	const std::string setting("opml-url");
 	const std::string url1("https://example.com/feeds.opml");
@@ -36,7 +33,7 @@ TEST_CASE("OpmlUrlReader::reload() reads URLs and tags from an OPML file",
 		"opml-url",
 		"file://" + utils::getcwd() + "/data/example.opml");
 
-	OpmlUrlReader reader(cfg);
+	OpmlUrlReader reader(cfg, "");
 
 	REQUIRE_NOTHROW(reader.reload());
 
@@ -88,7 +85,7 @@ TEST_CASE("OpmlUrlReader::reload() loads URLs from multiple sources",
 		+ " "
 		+ "file://" + cwd + "/data/example2.opml");
 
-	OpmlUrlReader reader(cfg);
+	OpmlUrlReader reader(cfg, "");
 
 	REQUIRE_NOTHROW(reader.reload());
 
@@ -151,7 +148,7 @@ TEST_CASE("OpmlUrlReader::reload() skips things that can't be parsed",
 		+ " "
 		+ "file://" + cwd + "/data/example2.opml");
 
-	OpmlUrlReader reader(cfg);
+	OpmlUrlReader reader(cfg, "");
 
 	REQUIRE_NOTHROW(reader.reload());
 
